function [u]=ode23a(neqn,t0,tf,u0,nsteps)
%
% Function ode23a computes an ODE solution by a fixed
% step, embedded RK (2,3) pair discussed by Shampine,
% L. F., I. Gladwell and S. Thompson, Solving ODEs with
% Matlab, Cambridge University Press, Cambridge, New York,
% 2003, p 54, Table 2.3.
%
% Argument list
%
%   neqn     number of first order ODEs
%
%   t0       initial value of independent variable
%
%   tf       final value of independent variable
%
%   u0       initial condition vector of length neqn
%
%   nsteps   number of ode23 steps
%
%   u        ODE solution vector of length neqn after
%            nsteps steps
%
% Integration step
  h=(tf-t0)/nsteps;
%
% nsteps ode23 steps
  for i=1:nsteps
%
%   ode23 step
    [t,u,e]=ssode23(neqn,t0,u0,h);
%
%   Reset base point values for next ode23 step
    u0=u;
    t0=t;
%
% Next ode23 step
  end
%
% End of ode23a
